# Changelog

## 2.0.0 (2024-12-16)

Full Changelog: [v1.1.0...v2.0.0](https://github.com/identety/identety-python-sdk/compare/v1.1.0...v2.0.0)

### Features

* **api:** manual updates ([68194d5](https://github.com/identety/identety-python-sdk/commit/68194d5645768252ee81d361d3ece9435b91cbcd))


### Chores

* go live ([#18](https://github.com/identety/identety-python-sdk/issues/18)) ([ca01a07](https://github.com/identety/identety-python-sdk/commit/ca01a071ab501b2350e02719c40322bb939c8ebb))
* update SDK settings ([#20](https://github.com/identety/identety-python-sdk/issues/20)) ([21336b3](https://github.com/identety/identety-python-sdk/commit/21336b371f5dd4153c534cf34b33db147f5a0675))

## 1.1.0 (2024-12-14)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/identety/identety-python-sdk/compare/v1.0.0...v1.1.0)

### Features

* **api:** manual updates ([#14](https://github.com/identety/identety-python-sdk/issues/14)) ([4e7df66](https://github.com/identety/identety-python-sdk/commit/4e7df664b650243b611da8e9c3e5bb820d06053e))
* **api:** manual updates ([#16](https://github.com/identety/identety-python-sdk/issues/16)) ([d20b3f4](https://github.com/identety/identety-python-sdk/commit/d20b3f4111a94674d169eca1b38da7807cd42da3))

## 1.0.0 (2024-12-14)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/identety/identety-python-sdk/compare/v0.1.0-alpha.1...v1.0.0)

### Features

* **api:** api update ([#11](https://github.com/identety/identety-python-sdk/issues/11)) ([14d255a](https://github.com/identety/identety-python-sdk/commit/14d255a1ce235bdac84db75ceaa5fd018abed779))
* **api:** api update ([#12](https://github.com/identety/identety-python-sdk/issues/12)) ([e418729](https://github.com/identety/identety-python-sdk/commit/e4187294ed9ec61339144f1059841b5957d49edf))
* **api:** manual updates ([bdd4e41](https://github.com/identety/identety-python-sdk/commit/bdd4e411ce2cc1179c94d44c6417a9ea5a13184f))


### Chores

* go live ([#8](https://github.com/identety/identety-python-sdk/issues/8)) ([dc446d1](https://github.com/identety/identety-python-sdk/commit/dc446d13d3712fddb516077d055606915a1f6500))
* update SDK settings ([#10](https://github.com/identety/identety-python-sdk/issues/10)) ([e5a0f1a](https://github.com/identety/identety-python-sdk/commit/e5a0f1a031cb8203c35b569e9943c32a3aeb1c61))

## 0.1.0-alpha.1 (2024-12-14)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/identety/identety-python-sdk/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** manual updates ([#5](https://github.com/identety/identety-python-sdk/issues/5)) ([27c8e66](https://github.com/identety/identety-python-sdk/commit/27c8e66ad55e6fc1103a73a0aad0bcccc83ccd86))

## 0.0.1-alpha.1 (2024-12-14)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/identety/identety-python-sdk/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/identety/identety-python-sdk/issues/1)) ([9e57fc1](https://github.com/identety/identety-python-sdk/commit/9e57fc19c9a52d9fedeffb292b6172642c9aa7d1))
* update SDK settings ([#3](https://github.com/identety/identety-python-sdk/issues/3)) ([8a5311d](https://github.com/identety/identety-python-sdk/commit/8a5311d4ada0c9ca745fe0c208e9302cb6132fc6))
